// Thank you, Sarah! (updated event handler)
// https://codepen.io/SarahC
//
// https://developer.mozilla.org/en-US/docs/Web/Events/wheel#Listening_to_this_event_across_browser
// creates a global "addWheelListener" method
// example: addWheelListener( elem, function( e ) { console.log( e.deltaY ); e.preventDefault(); } );
(function (window, document) {
  var prefix = "",_addEventListener,support;
  // detect event model
  if (window.addEventListener) {
    _addEventListener = "addEventListener";
  } else {
    _addEventListener = "attachEvent";
    prefix = "on";
  }
  // detect available wheel event
  support = "onwheel" in document.createElement("div") ? "wheel" : // Modern browsers support "wheel"
  document.onmousewheel !== undefined ? "mousewheel" : // Webkit and IE support at least "mousewheel"
  "DOMMouseScroll"; // let's assume that remaining browsers are older Firefox
  window.addWheelListener = function (elem, callback, useCapture) {
    _addWheelListener(elem, support, callback, useCapture);
    // handle MozMousePixelScroll in older Firefox
    if (support == "DOMMouseScroll") {
      _addWheelListener(elem, "MozMousePixelScroll", callback, useCapture);
    }
  };
  function _addWheelListener(elem, eventName, callback, useCapture) {
    elem[_addEventListener](prefix + eventName, support == "wheel" ? callback : function (originalEvent) {
      !originalEvent && (originalEvent = window.event);
      // create a normalized event object
      var event = {
        // keep a ref to the original event object
        originalEvent: originalEvent,
        target: originalEvent.target || originalEvent.srcElement,
        type: "wheel",
        deltaMode: originalEvent.type == "MozMousePixelScroll" ? 0 : 1,
        deltaX: 0,
        deltaY: 0,
        deltaZ: 0,
        preventDefault: function () {
          originalEvent.preventDefault ?
          originalEvent.preventDefault() :
          originalEvent.returnValue = false;
        } };

      // calculate deltaY (and deltaX) according to the event
      if (support == "mousewheel") {
        event.deltaY = -1 / 40 * originalEvent.wheelDelta;
        // Webkit also support wheelDeltaX
        originalEvent.wheelDeltaX && (event.deltaX = -1 / 40 * originalEvent.wheelDeltaX);
      } else {
        event.deltaY = originalEvent.deltaY || originalEvent.detail;
      }
      return callback(event);
    }, useCapture || false);
  }
})(window, document);

var topE = document.querySelector(".top .content");
var bottomE = document.querySelector(".bottom .content");
var backE = document.querySelector(".back .content");

addWheelListener(window, function (e) {
  var scrolled = parseInt(e.deltaY * 1.5);
  var currTop = parseInt(window.getComputedStyle(topE).top.split("px")[0]);
  var currBottom = parseInt(window.getComputedStyle(bottomE).bottom.split("px")[0]);
  var currBack = parseInt(window.getComputedStyle(backE).bottom.split("px")[0]);
  TweenMax.to(topE.style, 0.3, { top: currTop - scrolled + "px" });
  TweenMax.to(backE.style, 0.3, { bottom: currBack + scrolled + "px" });
  TweenMax.to(bottomE.style, 0.3, { bottom: currBottom + scrolled + "px" });
  e.preventDefault();
});